@@ -1,6 +1,6 @@
 use strict;
 package Web::Authenticate::Result::Authenticate;
-$Web::Authenticate::Result::Authenticate::VERSION = '0.007';
+$Web::Authenticate::Result::Authenticate::VERSION = '0.010';
 use Mouse;
 #ABSTRACT: The result of calling Web::Authenticate::authenticate.
 
@@ -9,6 +9,7 @@ has success => (
     isa => 'Bool',
     is => 'ro',
     required => 1,
+    default => undef,
 );
 
 
@@ -29,6 +30,24 @@ has auth_redir => (
     is => 'ro',
 );
 
+# remove undef arguments before constructed
+around 'BUILDARGS' => sub {
+  my($orig, $self, @params) = @_;
+  my $params;
+
+  if(@params == 1 ) {
+    ($params) = @params;
+  } else {
+    $params = { @params };
+  }
+
+  for my $key (keys %$params){
+    delete $params->{$key} unless defined $params->{$key};
+  }
+
+  $self->$orig($params);
+};
+
 1;
 
 __END__
@@ -43,7 +62,7 @@ Web::Authenticate::Result::Authenticate - The result of calling Web::Authenticat
 
 =head1 VERSION
 
-version 0.007
+version 0.010
 
 =head1 METHODS
 
