@@ -1,6 +1,6 @@
 use strict;
 package Web::Authenticate::Result::CreateUser;
-$Web::Authenticate::Result::CreateUser::VERSION = '0.005';
+$Web::Authenticate::Result::CreateUser::VERSION = '0.010';
 use Mouse;
 #ABSTRACT: The result of calling Web::Authenticate::create_user.
 
@@ -9,6 +9,7 @@ has success => (
     isa => 'Bool',
     is => 'ro',
     required => 1,
+    default => undef,
 );
 
 
@@ -31,6 +32,24 @@ has failed_password_verifiers => (
     default => sub { [] },
 );
 
+# remove undef arguments before constructed
+around 'BUILDARGS' => sub {
+  my($orig, $self, @params) = @_;
+  my $params;
+
+  if(@params == 1 ) {
+    ($params) = @params;
+  } else {
+    $params = { @params };
+  }
+
+  for my $key (keys %$params){
+    delete $params->{$key} unless defined $params->{$key};
+  }
+
+  $self->$orig($params);
+};
+
 1;
 
 __END__
@@ -45,7 +64,7 @@ Web::Authenticate::Result::CreateUser - The result of calling Web::Authenticate:
 
 =head1 VERSION
 
-version 0.005
+version 0.010
 
 =head1 METHODS
 
