@@ -1,6 +1,6 @@
 use strict;
 package Web::Authenticate::Result::Login;
-$Web::Authenticate::Result::Login::VERSION = '0.006';
+$Web::Authenticate::Result::Login::VERSION = '0.010';
 use Mouse;
 #ABSTRACT: The result of calling Web::Authenticate::login.
 
@@ -9,6 +9,15 @@ has success => (
     isa => 'Bool',
     is => 'ro',
     required => 1,
+    default => undef,
+);
+
+
+has invalid_username_or_password => (
+    isa => 'Bool',
+    is => 'ro',
+    lazy => 1,
+    default => sub { not shift->user },
 );
 
 
@@ -29,6 +38,24 @@ has auth_redir => (
     is => 'ro',
 );
 
+# remove undef arguments before constructed
+around 'BUILDARGS' => sub {
+  my($orig, $self, @params) = @_;
+  my $params;
+
+  if(@params == 1 ) {
+    ($params) = @params;
+  } else {
+    $params = { @params };
+  }
+
+  for my $key (keys %$params){
+    delete $params->{$key} unless defined $params->{$key};
+  }
+
+  $self->$orig($params);
+};
+
 1;
 
 __END__
@@ -43,7 +70,7 @@ Web::Authenticate::Result::Login - The result of calling Web::Authenticate::logi
 
 =head1 VERSION
 
-version 0.006
+version 0.010
 
 =head1 METHODS
 
@@ -51,9 +78,14 @@ version 0.006
 
 Returns 1 if the call to L<Web::Authenticate/login> was successful, undef otherwise.
 
+=head2 invalid_username_or_password
+
+Returns 1 if the username and/or password were invalid. Undef otherwise. This is the same as checking if
+L</user> is undef.
+
 =head2 user
 
-Returns the user that was logged in.
+Returns the user that was logged in. Checking if this is undef is the same as calling L</invalid_username_or_password>.
 
 =head2 failed_authenticator
 
